Forum Discussion
empty report issue
The compiling went through well, no compiling error. Thanks
Hi,
Can you check if you have gotten your main sources renamed, which may have caused the issue?
There is a related discussion that might related to this issue:
https://community.intel.com/t5/Software-Archive/Empty-Optimization-Report/m-p/1148246
- beiwang20036 years ago
New Contributor
No name changes. The vector_add.cl example only contains the following:
__kernel void vector_add(__global const float *x,
__global const float *y,
__global float *restrict z)
{
// get index of the work item
int index = get_global_id(0);
// add the vector elements
z[index] = x[index] + y[index];
}
- beiwang20036 years ago
New Contributor
The problem is fixed. I only copied the report.html file to my local computer to review with a browser. I will also need to copy the ./lib directory within ./reports to review the complete report. Thanks!